@@ -29,8 +29,8 @@ arg_number = 0
 bot_token = ""
 
 class simple_discord_bot(discord.Client):
-    def __init__(self, token):
-        self.token = token
+    def __init__(self):
+        pass
     def add_command(self, command_to_add, response, react_to=None, reaction=None, delete=False, connect_to_voicechannel=False, source_to_play=None, DM=False):
 
         command_dict[str(command_to_add)] = {
